@@ -4,6 +4,7 @@ from __future__ import annotations
 from dataclasses import dataclass
 from datetime import datetime
 from enum import Enum
+from functools import wraps
 from typing import TYPE_CHECKING, Any, Callable, Dict, List, cast
 
 from simplipy.const import LOGGER
@@ -17,9 +18,6 @@ from simplipy.util.string import convert_to_underscore
 if TYPE_CHECKING:
     from simplipy.api import API
 
-VERSION_V2 = 2
-VERSION_V3 = 3
-
 EVENT_SYSTEM_NOTIFICATION = "system_notification"
 
 CONF_DEFAULT = "default"
@@ -52,18 +50,18 @@ class SystemNotification:
 class SystemStates(Enum):
     """States that the system can be in."""
 
-    alarm = 1
-    alarm_count = 2
-    away = 3
-    away_count = 4
-    entry_delay = 5
-    error = 6
-    exit_delay = 7
-    home = 8
-    home_count = 9
-    off = 10
-    test = 11
-    unknown = 99
+    ALARM = 1
+    ALARM_COUNT = 2
+    AWAY = 3
+    AWAY_COUNT = 4
+    ENTRY_DELAY = 5
+    ERROR = 6
+    EXIT_DELAY = 7
+    HOME = 8
+    HOME_COUNT = 9
+    OFF = 10
+    TEST = 11
+    UNKNOWN = 99
 
 
 def get_device_type_from_data(device_data: dict[str, Any]) -> DeviceTypes:
@@ -72,7 +70,7 @@ def get_device_type_from_data(device_data: dict[str, Any]) -> DeviceTypes:
         return DeviceTypes(device_data["type"])
     except ValueError:
         LOGGER.error("Unknown device type: %s", device_data["type"])
-        return DeviceTypes.unknown
+        return DeviceTypes.UNKNOWN
 
 
 def guard_from_missing_data(default_value: Any = None) -> Callable:
@@ -81,6 +79,7 @@ def guard_from_missing_data(default_value: Any = None) -> Callable:
     def decorator(func: Callable) -> Callable:
         """Decorate."""
 
+        @wraps(func)
         def wrapper(system: "System") -> Any:
             """Call the function and handle any issue."""
             try:
@@ -115,7 +114,7 @@ class System:
 
         # These will get filled in after initial update:
         self._notifications: list[SystemNotification] = []
-        self._state = SystemStates.unknown
+        self._state = SystemStates.UNKNOWN
         self.sensor_data: dict[str, dict[str, Any]] = {}
         self.sensors: dict[str, SensorV2 | SensorV3] = {}
 
@@ -323,15 +322,15 @@ class System:
 
     async def async_set_away(self) -> None:
         """Set the system in "Away" mode."""
-        await self._async_set_state(SystemStates.away)
+        await self._async_set_state(SystemStates.AWAY)
 
     async def async_set_home(self) -> None:
         """Set the system in "Home" mode."""
-        await self._async_set_state(SystemStates.home)
+        await self._async_set_state(SystemStates.HOME)
 
     async def async_set_off(self) -> None:
         """Set the system in "Off" mode."""
-        await self._async_set_state(SystemStates.off)
+        await self._async_set_state(SystemStates.OFF)
 
     async def async_set_pin(self, label: str, pin: str) -> None:
         """Set a PIN.
@@ -416,7 +415,7 @@ class System:
         )
 
         try:
-            self._state = SystemStates[convert_to_underscore(raw_state)]
+            self._state = SystemStates[convert_to_underscore(raw_state).upper()]
         except KeyError:
             LOGGER.error("Unknown raw system state: %s", raw_state)
-            self._state = SystemStates.unknown
+            self._state = SystemStates.UNKNOWN
