@@ -2,7 +2,8 @@
 from __future__ import annotations
 
 from datetime import datetime, timedelta
-from typing import TYPE_CHECKING, cast
+from enum import Enum
+from typing import TYPE_CHECKING, Final, cast
 
 import voluptuous as vol
 
@@ -36,46 +37,64 @@ CONF_VOICE_PROMPT_VOLUME = "voice_prompt_volume"
 
 DEFAULT_LOCK_STATE_CHANGE_WINDOW = timedelta(seconds=15)
 
-VOLUME_OFF = 0
-VOLUME_LOW = 1
-VOLUME_MEDIUM = 2
-VOLUME_HIGH = 3
-VOLUMES = [VOLUME_OFF, VOLUME_LOW, VOLUME_MEDIUM, VOLUME_HIGH]
 
 SYSTEM_PROPERTIES_VALUE_MAP = {
-    "alarm_duration": "alarmDuration",
-    "alarm_volume": "alarmVolume",
-    "chime_volume": "doorChime",
-    "entry_delay_away": "entryDelayAway",
-    "entry_delay_home": "entryDelayHome",
-    "exit_delay_away": "exitDelayAway",
-    "exit_delay_home": "exitDelayHome",
-    "light": "light",
-    "voice_prompt_volume": "voicePrompts",
+    CONF_ALARM_DURATION: "alarmDuration",
+    CONF_ALARM_VOLUME: "alarmVolume",
+    CONF_CHIME_VOLUME: "doorChime",
+    CONF_ENTRY_DELAY_AWAY: "entryDelayAway",
+    CONF_ENTRY_DELAY_HOME: "entryDelayHome",
+    CONF_EXIT_DELAY_AWAY: "exitDelayAway",
+    CONF_EXIT_DELAY_HOME: "exitDelayHome",
+    CONF_LIGHT: "light",
+    CONF_VOICE_PROMPT_VOLUME: "voicePrompts",
 }
 
+MIN_ALARM_DURATION: Final = 30
+MAX_ALARM_DURATION: Final = 480
+MIN_ENTRY_DELAY_AWAY: Final = 30
+MAX_ENTRY_DELAY_AWAY: Final = 255
+MIN_ENTRY_DELAY_HOME: Final = 0
+MAX_ENTRY_DELAY_HOME: Final = 255
+MIN_EXIT_DELAY_AWAY: Final = 45
+MAX_EXIT_DELAY_AWAY: Final = 255
+MIN_EXIT_DELAY_HOME: Final = 0
+MAX_EXIT_DELAY_HOME: Final = 255
+
+
+class Volume(Enum):
+    """Define a representation of a SimpliSafe volume level."""
+
+    OFF = 0
+    LOW = 1
+    MEDIUM = 2
+    HIGH = 3
+
+
 SYSTEM_PROPERTIES_PAYLOAD_SCHEMA = vol.Schema(
     {
         vol.Optional(CONF_ALARM_DURATION): vol.All(
-            vol.Coerce(int), vol.Range(min=30, max=480)
+            vol.Coerce(int), vol.Range(min=MIN_ALARM_DURATION, max=MAX_ALARM_DURATION)
         ),
-        vol.Optional(CONF_ALARM_VOLUME): vol.All(vol.Coerce(int), vol.In(VOLUMES)),
-        vol.Optional(CONF_CHIME_VOLUME): vol.All(vol.Coerce(int), vol.In(VOLUMES)),
+        vol.Optional(CONF_ALARM_VOLUME): vol.All(Volume, lambda volume: volume.value),
+        vol.Optional(CONF_CHIME_VOLUME): vol.All(Volume, lambda volume: volume.value),
         vol.Optional(CONF_ENTRY_DELAY_AWAY): vol.All(
-            vol.Coerce(int), vol.Range(min=30, max=255)
+            vol.Coerce(int),
+            vol.Range(min=MIN_ENTRY_DELAY_AWAY, max=MAX_ENTRY_DELAY_AWAY),
         ),
         vol.Optional(CONF_ENTRY_DELAY_HOME): vol.All(
-            vol.Coerce(int), vol.Range(min=0, max=255)
+            vol.Coerce(int),
+            vol.Range(min=MIN_ENTRY_DELAY_HOME, max=MAX_ENTRY_DELAY_HOME),
         ),
         vol.Optional(CONF_EXIT_DELAY_AWAY): vol.All(
-            vol.Coerce(int), vol.Range(min=45, max=255)
+            vol.Coerce(int), vol.Range(min=MIN_EXIT_DELAY_AWAY, max=MAX_EXIT_DELAY_AWAY)
         ),
         vol.Optional(CONF_EXIT_DELAY_HOME): vol.All(
-            vol.Coerce(int), vol.Range(min=0, max=255)
+            vol.Coerce(int), vol.Range(min=MIN_EXIT_DELAY_HOME, max=MAX_EXIT_DELAY_HOME)
         ),
         vol.Optional(CONF_LIGHT): bool,
         vol.Optional(CONF_VOICE_PROMPT_VOLUME): vol.All(
-            vol.Coerce(int), vol.In(VOLUMES)
+            Volume, lambda volume: volume.value
         ),
     }
 )
@@ -142,15 +161,17 @@ class SystemV3(System):  # pylint: disable=too-many-public-methods
 
     @property  # type: ignore
     @guard_from_missing_data()
-    def alarm_volume(self) -> int:
+    def alarm_volume(self) -> Volume:
         """Return the volume level of the alarm.
 
         :rtype: ``int``
         """
-        return int(
-            self.settings_data["settings"]["normal"][
-                SYSTEM_PROPERTIES_VALUE_MAP["alarm_volume"]
-            ]
+        return Volume(
+            int(
+                self.settings_data["settings"]["normal"][
+                    SYSTEM_PROPERTIES_VALUE_MAP["alarm_volume"]
+                ]
+            )
         )
 
     @property  # type: ignore
@@ -164,15 +185,17 @@ class SystemV3(System):  # pylint: disable=too-many-public-methods
 
     @property  # type: ignore
     @guard_from_missing_data()
-    def chime_volume(self) -> int:
+    def chime_volume(self) -> Volume:
         """Return the volume level of the door chime.
 
         :rtype: ``int``
         """
-        return int(
-            self.settings_data["settings"]["normal"][
-                SYSTEM_PROPERTIES_VALUE_MAP["chime_volume"]
-            ]
+        return Volume(
+            int(
+                self.settings_data["settings"]["normal"][
+                    SYSTEM_PROPERTIES_VALUE_MAP["chime_volume"]
+                ]
+            )
         )
 
     @property  # type: ignore
@@ -289,16 +312,17 @@ class SystemV3(System):  # pylint: disable=too-many-public-methods
 
     @property  # type: ignore
     @guard_from_missing_data()
-    def voice_prompt_volume(self) -> int:
+    def voice_prompt_volume(self) -> Volume:
         """Return the volume level of the voice prompt.
 
         :rtype: ``int``
         """
-        return cast(
-            int,
-            self.settings_data["settings"]["normal"][
-                SYSTEM_PROPERTIES_VALUE_MAP["voice_prompt_volume"]
-            ],
+        return Volume(
+            int(
+                self.settings_data["settings"]["normal"][
+                    SYSTEM_PROPERTIES_VALUE_MAP["voice_prompt_volume"]
+                ]
+            )
         )
 
     @property  # type: ignore
@@ -345,7 +369,7 @@ class SystemV3(System):  # pylint: disable=too-many-public-methods
     async def _async_set_state(self, value: SystemStates) -> None:
         """Set the state of the system."""
         await self._api.request(
-            "post", f"ss3/subscriptions/{self.system_id}/state/{value.name}"
+            "post", f"ss3/subscriptions/{self.system_id}/state/{value.name.lower()}"
         )
 
         self._state = value
@@ -390,13 +414,13 @@ class SystemV3(System):  # pylint: disable=too-many-public-methods
         """Generate device objects for this system."""
         for serial, sensor in self.sensor_data.items():
             sensor_type = get_device_type_from_data(sensor)
-            if sensor_type == DeviceTypes.lock:
+            if sensor_type == DeviceTypes.LOCK:
                 self.locks[serial] = Lock(self._api.request, self, sensor_type, serial)
             else:
                 self.sensors[serial] = SensorV3(self, sensor_type, serial)
 
         for serial in self.camera_data:
-            self.cameras[serial] = Camera(self, DeviceTypes.camera, serial)
+            self.cameras[serial] = Camera(self, DeviceTypes.CAMERA, serial)
 
     async def async_get_pins(self, cached: bool = True) -> dict[str, str]:
         """Return all of the set PINs, including master and duress.
@@ -422,25 +446,29 @@ class SystemV3(System):  # pylint: disable=too-many-public-methods
 
         return pins
 
-    async def async_set_properties(self, properties: dict) -> None:
+    async def async_set_properties(
+        self, properties: dict[str, bool | int | Volume]
+    ) -> None:
         """Set various system properties.
 
+        Volume properties should take values from :meth:`simplipy.system.v3.Volume`.
+
         The following properties can be set:
            1. alarm_duration (in seconds): 30-480
-           2. alarm_volume: 0 (off), 1 (low), 2 (medium), 3 (high)
-           3. chime_volume: 0 (off), 1 (low), 2 (medium), 3 (high)
+           2. alarm_volume: Volume.OFF, Volume.LOW, Volume.MEDIUM, Volume.HIGH
+           3. chime_volume: Volume.OFF, Volume.LOW, Volume.MEDIUM, Volume.HIGH
            4. entry_delay_away (in seconds): 30-255
            5. entry_delay_home (in seconds): 0-255
            6. exit_delay_away (in seconds): 45-255
            7. exit_delay_home (in seconds): 0-255
            8. light: True or False
-           9. voice_prompt_volume: 0 (off), 1 (low), 2 (medium), 3 (high)
+           9. voice_prompt_volume: Volume.OFF, Volume.LOW, Volume.MEDIUM, Volume.HIGH
 
         :param properties: The system properties to set.
         :type properties: ``dict``
         """
         try:
-            SYSTEM_PROPERTIES_PAYLOAD_SCHEMA(properties)
+            parsed_properties = SYSTEM_PROPERTIES_PAYLOAD_SCHEMA(properties)
         except vol.Invalid as err:
             raise ValueError(
                 f"Using invalid values for system properties ({properties}): {err}"
@@ -452,7 +480,7 @@ class SystemV3(System):  # pylint: disable=too-many-public-methods
             json={
                 "normal": {
                     SYSTEM_PROPERTIES_VALUE_MAP[prop]: value
-                    for prop, value in properties.items()
+                    for prop, value in parsed_properties.items()
                 }
             },
         )
